//
//  StatusCode.swift
//  NetworkObjects
//
//  Created by Alsey Coleman Miller on 6/24/15.
//  Copyright © 2015 ColemanCDA. All rights reserved.
//

/** These HTTP status code returned from NetworkObjects servers. */
public enum StatusCode: Int {
    
    /** OK status code. */
    case OK = 200
    
    /** Bad request status code. */
    case BadRequest = 400
    
    /** Unauthorized status code. e.g. Used when authentication is required. */
    case Unauthorized = 401
    
    case PaymentRequired = 402
    
    /** Forbidden status code. e.g. Used when permission is denied. */
    case Forbidden = 403
    
    /** Not Found status code. e.g. Used when a Resource instance cannot be found. */
    case NotFound = 404
    
    /** Method Not Allowed status code. e.g. Used for invalid requests. */
    case MethodNotAllowed = 405
    
    /** Conflict status code. e.g. Used when a user with the specified username already exists. */
    case Conflict = 409
    
    /** Internal Server Error status code. e.g. Used when a JSON cannot be converted to NSData for a HTTP response. */
    case InternalServerError = 500
    
    func toErrorStatusCode() -> ErrorStatusCode? {
        
        return ErrorStatusCode(rawValue: self.rawValue)
    }
}